==> cdktf-cdktf-provider-docker-0.0.64.tar.gz: package/lib/data-docker-network.d.ts <==
import { Construct } from 'constructs';
import { TerraformDataSource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 * @stability stable
 */
export interface DataDockerNetworkConfig extends TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class DataDockerNetworkIpamConfig extends ComplexComputedList {
    /**
     * @stability stable
     */
    get auxAddress(): any;
    /**
     * @stability stable
     */
    get gateway(): string;
    /**
     * @stability stable
     */
    get ipRange(): string;
    /**
     * @stability stable
     */
    get subnet(): string;
}
/**
 * @stability stable
 */
export declare class DataDockerNetwork extends TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataDockerNetworkConfig);
    /**
     * @stability stable
     */
    get driver(): string;
    private _id?;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    set id(value: string);
    /**
     * @stability stable
     */
    resetId(): void;
    /**
     * @stability stable
     */
    get idInput(): string | undefined;
    /**
     * @stability stable
     */
    get internal(): boolean;
    /**
     * @stability stable
     */
    ipamConfig(index: string): DataDockerNetworkIpamConfig;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    options(key: string): string;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-docker-0.0.84.tar.gz: package/lib/data-docker-network.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataDockerNetworkConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class DataDockerNetworkIpamConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get auxAddress(): any;
    /**
     * @stability stable
     */
    get gateway(): string;
    /**
     * @stability stable
     */
    get ipRange(): string;
    /**
     * @stability stable
     */
    get subnet(): string;
}
/**
 * @stability stable
 */
export declare class DataDockerNetwork extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataDockerNetworkConfig);
    /**
     * @stability stable
     */
    get driver(): string;
    private _id?;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    set id(value: string);
    /**
     * @stability stable
     */
    resetId(): void;
    /**
     * @stability stable
     */
    get idInput(): string | undefined;
    /**
     * @stability stable
     */
    get internal(): boolean;
    /**
     * @stability stable
     */
    ipamConfig(index: string): DataDockerNetworkIpamConfig;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    options(key: string): string;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
